"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var fuse_box_1 = require("fuse-box");
var ng_compiler_plugin_1 = require("./tools/plugins/ng.compiler.plugin");
var yargs_1 = require("yargs");
var ng_polyfill_plugin_1 = require("./tools/plugins/ng.polyfill.plugin");
var ng_prod_plugin_1 = require("./tools/plugins/ng.prod.plugin");
var ng_optimizer_plugin_1 = require("./tools/plugins/ng.optimizer.plugin");
var ng_server_module_plugin_1 = require("./tools/plugins/ng.server.module.plugin");
var ng_bootstrap_plugin_1 = require("./tools/plugins/ng.bootstrap.plugin");
var DEFAULT_CONFIG = {
    enableAotCompilaton: yargs_1.argv.aot,
    productionBuild: yargs_1.argv.prod,
    supportIE11: true,
    supportIE11Animations: false,
    enableAngularAnimations: false,
    enableAngularForms: false,
    enableServiceWorker: false,
    serverPort: process.env.PORT && +process.env.PORT || 5000,
    angularServerModule: {
        moduleName: 'AppServerModule',
        modulePath: 'src/server/server.angular.module'
    }
};
exports.fusingAngular = function (opts) {
    var settings = __assign({}, DEFAULT_CONFIG, opts);
    return {
        run: function () {
            var fuseBrowser = fuse_box_1.FuseBox.init({
                homeDir: "./",
                output: "./.dist/public/js/$name.js",
                target: 'browser@es5',
                cache: !settings.productionBuild,
                plugins: [
                    ng_bootstrap_plugin_1.NgBootstrapPlugin({ enabled: settings.enableAotCompilaton }),
                    ng_prod_plugin_1.NgProdPlugin({ enabled: settings.productionBuild }),
                    ng_polyfill_plugin_1.NgPolyfillPlugin(),
                    ng_compiler_plugin_1.NgCompilerPlugin({ enabled: settings.enableAotCompilaton }),
                    ng_optimizer_plugin_1.NgOptimizerPlugin({ enabled: settings.enableAngularBuildOptimizer }),
                    settings.productionBuild && fuse_box_1.QuantumPlugin({
                        bakeApiIntoBundle: 'vendor',
                        warnings: false,
                        uglify: true,
                        treeshake: true,
                        ensureES5: true
                    })
                ]
            });
            var mainAppEntry = 'app.browser.module.ts';
            var fuseServer = fuse_box_1.FuseBox.init({
                target: 'server@es5',
                homeDir: "./",
                output: "./.dist/$name.js",
                cache: !settings.productionBuild,
                plugins: [
                    fuse_box_1.EnvPlugin({ serverPort: settings.serverPort }),
                    ng_prod_plugin_1.NgProdPlugin({ enabled: settings.productionBuild, fileTest: 'server.angular.module' }),
                    settings.angularServerModule && ng_server_module_plugin_1.NgServerModulePlugin({
                        module: settings.angularServerModule.moduleName,
                        path: settings.angularServerModule.modulePath
                    }),
                    ng_polyfill_plugin_1.NgPolyfillPlugin({ isServer: true, fileTest: 'server.angular.module' })
                ]
            });
            var vendorBundle = fuseBrowser.bundle('vendor');
            var appBundle = fuseBrowser.bundle('app');
            var serverBundle = fuseServer.bundle("server");
            vendorBundle.instructions(" ~ src/browser/" + mainAppEntry);
            appBundle.instructions(" !> [src/browser/" + mainAppEntry + "]");
            serverBundle
                .instructions(" > [src/server/server.ts]")
                .completed(function (proc) { return proc.start(); });
            if (!settings.productionBuild) {
                appBundle.watch('src/**');
                serverBundle.watch("src/**");
                fuseServer.dev({
                    root: './.dist',
                    port: settings.serverPort,
                    httpServer: false
                });
            }
            fuseBrowser.run();
            fuseServer.run();
        }
    };
};
var app = exports.fusingAngular({
    productionBuild: true,
    enableAotCompilaton: true
});
app.run();
//# sourceMappingURL=index.js.map